@@ -1,10 +1,40 @@
 package Chart::Clicker::Renderer::Base;
 use strict;
+use warnings;
 
 use base 'Chart::Clicker::Drawing::Component';
-__PACKAGE__->mk_accessors(
-    qw(options)
-);
+__PACKAGE__->mk_accessors( qw(options) );
+
+sub get_option {
+    my $self = shift();
+    my $key = shift();
+
+    if(defined($self->options())) {
+        return $self->options()->{$key};
+    }
+
+    return;
+}
+
+sub prepare {
+    my $self = shift();
+    my $clicker = shift();
+    my $dimension = shift();
+
+    $self->width($dimension->width());
+    $self->height($dimension->height());
+
+    return 1;
+}
+
+## no critic
+sub render {
+    die('Override me.');
+}
+## use critic
+
+1;
+__END__
 
 =head1 NAME
 
@@ -16,7 +46,7 @@ Chart::Clicker::Renderer::Base represents the plot of the chart.
 
 =head1 SYNOPSIS
 
-=cut
+  my $renderer = new Chart::Clicker::Renderer::Foo();
 
 =head1 METHODS
 
@@ -38,39 +68,14 @@ Creates a new Chart::Clicker::Renderer::Base.
 
 Returns a value for the specified key (if it exists) from the options hashref.
 
-=cut
-sub get_option {
-    my $self = shift();
-    my $key = shift();
-
-    if(defined($self->options())) {
-        return $self->options()->{$key};
-    }
-}
-
 =item prepare
 
 Prepare the component.
 
-=cut
-sub prepare {
-    my $self = shift();
-    my $clicker = shift();
-    my $dimension = shift();
-
-    $self->width($dimension->width());
-    $self->height($dimension->height());
-}
-
 =item render
 
 Render the series.
 
-=cut
-sub render {
-    die('Override me.');
-}
-
 =back
 
 =head1 AUTHOR
@@ -81,6 +86,7 @@ Cory 'G' Watson <gphat@cpan.org>
 
 perl(1)
 
-=cut
+=head1 LICENSE
 
-1;
+You can redistribute and/or modify this code under the same terms as Perl
+itself.
